Alien::libmaxminddb

DP-IP.com and MaxMind provide geolocation databases in the MaxMind DB file format format. This Perl module finds or downloads and installs the C library libmaxminddb, which can read MaxMind DB files.

DEPENDENCIES

Requires Alien::Build from CPAN. On Windows, Alien::MSYS needs to be installed.

Install the package libmaxminddb-devel or libmaxminddb-dev if you would like to use your operating system's libmaxminddb library.

INSTALLATION

The Open Build Service provides binary and source packages.

Run the following commands to install the software manually:

perl Makefile.PL
make
make test
make install

Type the following command to see the module usage information:

perldoc Alien::libmaxminddb

Copyright 2021 Andreas Vögele

This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.